@@ -360,7 +360,7 @@ class RetrieverSkeleton(ConfigurableBase):
                     self.oldmail[msgid] = int(timestamp)
                 except ValueError:
                     # malformed
-                    self.log.info('skipped malformed line "%r" for %s' 
+                    self.log.info('skipped malformed line "%r" for %s'
                                   % (line, self)
                                   + os.linesep)
             self.log.moreinfo('read %i uids for %s' % (len(self.oldmail), self)
@@ -535,7 +535,10 @@ class POP3RetrieverBase(RetrieverSkeleton):
             msg = Message(fromlines=lines)
             return msg
         except poplib.error_proto, o:
-            raise getmailOperationError('POP error (%s)' % o)
+            raise getmailRetrievalError(
+                'failed to retrieve msgid %s; server said %s' 
+                % (msgid, o)
+            )
 
     def _getheaderbyid(self, msgid):
         self.log.trace()
@@ -782,7 +785,7 @@ class IMAPRetrieverBase(RetrieverSkeleton):
         self.log.debug('selecting mailbox "%s"' % mailbox + os.linesep)
         try:
             response = self._parse_imapcmdresponse('SELECT', mailbox)
-            count = int(response[0])
+            count = int(response[-1]) # use *last* EXISTS returned
             uidvalidity = self.conn.response('UIDVALIDITY')[1][0]
         except imaplib.IMAP4.error, o:
             raise getmailOperationError('IMAP error (%s)' % o)
@@ -855,7 +858,15 @@ class IMAPRetrieverBase(RetrieverSkeleton):
             # Retrieve message
             self.log.debug('retrieving body for message "%s"' % uid
                            + os.linesep)
-            response = self._parse_imapuidcmdresponse('FETCH', uid, part)
+            try:
+                response = self._parse_imapuidcmdresponse('FETCH', uid, part)
+            except (imaplib.IMAP4.error, getmailOperationError), o:
+                # server gave a negative/NO response, most likely.  Bad server,
+                # no doughnut.
+                raise getmailRetrievalError(
+                    'failed to retrieve msgid %s; server said %s' 
+                    % (msgid, o)
+                )
             # Response is really ugly:
             #
             # [
@@ -866,7 +877,16 @@ class IMAPRetrieverBase(RetrieverSkeleton):
             #   ')',
             #   <maybe more>
             # ]
-            msg = Message(fromstring=response[0][1])
+            
+            # MSExchange is broken -- if a message is badly formatted enough
+            # (virus, spam, trojan), it can completely fail to return the
+            # message when requested.
+            try:
+                msg = Message(fromstring=response[0][1])
+            except TypeError, o:
+                # response[0] is None instead of a message tuple
+                raise getmailRetrievalError('failed to retrieve msgid %s' 
+                                            % msgid)
             return msg
 
         except imaplib.IMAP4.error, o:
